@@ -9,7 +9,7 @@ Tk::Poplevel - Popping a toplevel without decoration relative to a widget
 use strict;
 use warnings;
 use vars qw($VERSION);
-$VERSION = '0.08';
+$VERSION = '0.09';
 
 use base qw(Tk::Derived Tk::Toplevel);
 
@@ -59,12 +59,8 @@ Does nothing when B<-confine> is set.
 
 =item B<-widget>
 
-Mandatory!
-
 Set and return a reference to the widget the Poplevel should pop relative to.
 
-Only available at create time.
-
 =back
 
 =head1 METHODS
@@ -76,13 +72,9 @@ Only available at create time.
 sub Populate {
 	my ($self,$args) = @_;
 	
-	my $widget = delete $args->{'-widget'};
-	die 'You need to set the -widget option' unless defined $widget;
-
 	$self->SUPER::Populate($args);
 
 	$self->{POPDIRECTION} = '';
-	$self->{WIDGET} = $widget;
 	
 	$self->overrideredirect(1);
 	$self->withdraw;
@@ -104,7 +96,7 @@ sub Populate {
 		-popalign => ['PASSIVE', undef, undef, 'left'],
 		-popdirection => ['PASSIVE', undef, undef, 'down'],
 		-relief => [$self, 'relief', 'Relief', 'raised'],
-		-widget => ['PASSIVE', undef, undef, $widget],
+		-widget => ['PASSIVE'],
 		DEFAULT => [ $self ],
 	);
 }
